"use strict";
// Copyright (C) Microsoft Corporation. All rights reserved.
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const child_process_1 = require("child_process");
const diagnosticMessages_generated_1 = require("../diagnosticMessages.generated");
const locale_1 = require("../generated/locale");
class StartHarnessTask {
    constructor(watchOn) {
        this._watchOn = watchOn;
    }
    getDescription() {
        return locale_1.translate(diagnosticMessages_generated_1.strings.task_start_harness.key);
    }
    setOptions(options) {
        this._options = options;
    }
    run(context) {
        const outDir = context.getOutDir();
        if (!outDir) {
            context.getDiagnostic().push(diagnosticMessages_generated_1.strings.buildconfig_no_outdir);
            return Promise.reject();
        }
        const controls = fs.readdirSync(outDir);
        if (controls.length === 0) {
            context.getDiagnostic().push(diagnosticMessages_generated_1.strings.pcf_scripts_start_missing_control);
            return Promise.reject();
        }
        return new Promise((globalResolve, globalReject) => {
			const promises = [];
			controls.forEach((control) =>
			{
				const outputDir = path.join(outDir, control);
				// spawn a child process of pcf-start to launch the harness locally
				const pcfStartCmd = child_process_1.spawn('cmd', ['/c', `pcf-start ${this._watchOn ? '--watch' : ''} --codePath ${outputDir}`]);
				pcfStartCmd.stdout.on('data', (data) => {
					console.log(data.toString());
				});
				pcfStartCmd.stderr.on('data', (data) => {
					console.log(data.toString());
				});
				promises.push(new Promise((reject, resolve) => {
					pcfStartCmd.on('close', (code) => {
						if (code !== 0) {
							context.getDiagnostic().pushA(diagnosticMessages_generated_1.strings.pcf_start_exited, [code]);
							return reject();
						}
						else {
							return resolve();
						}
					})
				}));
			});
			Promise.all(promises).then(globalResolve, globalReject);
        });
    }
}
exports.StartHarnessTask = StartHarnessTask;
